@@ -42,8 +42,7 @@ if sys.platform == "win32":
             traceback.print_exc()
 
 
-from meadowrun.run_job import (
-    AllocCloudInstance,
+from meadowrun.deployment_spec import (
     AwsSecret,
     AzureSecret,
     CondaEnvironmentYmlFile,
@@ -59,17 +58,27 @@ from meadowrun.run_job import (
     PipRequirementsFile,
     PoetryProjectPath,
     Secret,
+)
+from meadowrun.kubernetes_integration import Kubernetes
+from meadowrun.run_job import (
+    AllocCloudInstance,
+    TaskResult,
     run_command,
     run_function,
     run_map,
+    run_map_as_completed,
 )
+from meadowrun.run_job_core import Resources, SshHost, TaskException
 from meadowrun.run_job_local import Host, LocalHost
-from meadowrun.run_job_core import Resources, SshHost
-from meadowrun.kubernetes_integration import Kubernetes
-
+from meadowrun.version import __version__
 
 __all__ = [
+    "__version__",
     "AllocCloudInstance",
+    "run_command",
+    "run_function",
+    "run_map",
+    "run_map_as_completed",
     "AwsSecret",
     "AzureSecret",
     "CondaEnvironmentYmlFile",
@@ -85,12 +94,11 @@ __all__ = [
     "PipRequirementsFile",
     "PoetryProjectPath",
     "Secret",
-    "run_command",
-    "run_function",
-    "run_map",
     "Host",
     "LocalHost",
     "Resources",
     "SshHost",
     "Kubernetes",
+    "TaskResult",
+    "TaskException",
 ]
