@@ -67,26 +67,26 @@ from meadowrun.run_job_core import JobCompletion, SshHost
 # replicate into each region.
 _AMIS = {
     "plain": {
-        "us-east-2": "ami-08766f069e82a723d",
-        "us-east-1": "ami-007175f8ebc9b7403",
-        "us-west-1": "ami-0ff608d06f5151d38",
-        "us-west-2": "ami-0339ed7ea96c87620",
-        "eu-central-1": "ami-096ea2c6825846c78",
-        "eu-west-1": "ami-05f662e3d0efb4cc9",
-        "eu-west-2": "ami-0b41c4ec6f7169a94",
-        "eu-west-3": "ami-0e20d27f93f34352c",
-        "eu-north-1": "ami-0f1b0711aee472818",
+        "us-east-2": "ami-060b22d1a6cc2015d",
+        "us-east-1": "ami-00ddb42386d3b53a7",
+        "us-west-1": "ami-0ad21db87a876b6a3",
+        "us-west-2": "ami-078c08b39693de44a",
+        "eu-central-1": "ami-0eacfa886550c9ebf",
+        "eu-west-1": "ami-0e9ef4f6ab8e046d9",
+        "eu-west-2": "ami-02bd2b9d2570224ad",
+        "eu-west-3": "ami-09d8d5eb88a3448c2",
+        "eu-north-1": "ami-0662349972ea33070",
     },
     "cuda": {
-        "us-east-2": "ami-0b9f9011ae18b5d4f",
-        "us-east-1": "ami-0e0769031ea69f297",
-        "us-west-1": "ami-043e3443dba006c3c",
-        "us-west-2": "ami-03f9617f990fae806",
-        "eu-central-1": "ami-0a5182ba83a42ecab",
-        "eu-west-1": "ami-0b994ff5c4534a740",
-        "eu-west-2": "ami-05d686d8a98f6f513",
-        "eu-west-3": "ami-0b2502d2572fe31e8",
-        "eu-north-1": "ami-0e87e280b496c8628",
+        "us-east-2": "ami-0812c941def86f2d0",
+        "us-east-1": "ami-0830a4ce808fc181c",
+        "us-west-1": "ami-08b7e850b0322cf84",
+        "us-west-2": "ami-028f438b7f6adf083",
+        "eu-central-1": "ami-08fccdf3fa0021fe2",
+        "eu-west-1": "ami-0278ff8a8933ec7fc",
+        "eu-west-2": "ami-0afd03a83578577ce",
+        "eu-west-3": "ami-07cee6f65999ac8d2",
+        "eu-north-1": "ami-0e5183ba0f8a902a5",
     },
 }
 SSH_USER = "ubuntu"
@@ -471,6 +471,7 @@ async def run_job_ec2_instance_registrar(
     job: Job,
     resources_required: ResourcesInternal,
     region_name: Optional[str],
+    wait_for_result: bool,
 ) -> JobCompletion[Any]:
     """Runs the specified job on EC2. Creates an EC2InstanceRegistrar"""
     region_name = region_name or await _get_default_region_name()
@@ -496,5 +497,5 @@ async def run_job_ec2_instance_registrar(
     job.job_id = job_ids[0]
 
     return await SshHost(host, SSH_USER, pkey, ("EC2", region_name)).run_job(
-        resources_required, job
+        resources_required, job, wait_for_result
     )
