@@ -1,16 +1,17 @@
 """Manages local deployments for run_job_local"""
 
+from __future__ import annotations
+
 import asyncio.subprocess
+import functools
 import hashlib
 import os
 import shutil
 import tempfile
 import urllib.parse
-import zipfile
 from typing import (
-    Any,
+    Awaitable,
     Callable,
-    Coroutine,
     List,
     Mapping,
     Optional,
@@ -22,15 +23,14 @@ from typing import (
 import filelock
 
 from meadowrun._vendor.aiodocker import exceptions as aiodocker_exceptions
-from meadowrun.aws_integration import s3
 from meadowrun.aws_integration.ecr import (
     get_ecr_helper,
 )
 from meadowrun.aws_integration.management_lambdas.ec2_alloc_stub import (
     _MEADOWRUN_GENERATED_DOCKER_REPO,
 )
-from meadowrun.azure_integration import blob_storage
 from meadowrun.azure_integration.acr import get_acr_helper
+from meadowrun.conda import get_cached_or_create_conda_environment
 from meadowrun.credentials import RawCredentials, SshKey
 from meadowrun.docker_controller import (
     _does_digest_exist_locally,
@@ -38,14 +38,29 @@ from meadowrun.docker_controller import (
     pull_image,
     push_image,
 )
+from meadowrun.func_worker_storage_helper import FuncWorkerClientObjectStorage
 from meadowrun.meadowrun_pb2 import (
+    CodeZipFile,
     EnvironmentSpec,
     EnvironmentSpecInCode,
     EnvironmentType,
     Job,
     ServerAvailableContainer,
+    ServerAvailableInterpreter,
 )
-from meadowrun.run_job_core import CloudProviderType, ContainerRegistryHelper
+from meadowrun.pip_integration import get_cached_or_create_pip_environment
+from meadowrun.poetry_integration import get_cached_or_create_poetry_environment
+from meadowrun.run_job import S3ObjectStorage, AzureBlobStorage
+from meadowrun.run_job_core import (
+    CloudProviderType,
+    ContainerRegistryHelper,
+    LocalObjectStorage,
+)
+from meadowrun.func_worker_storage_helper import (
+    try_get_storage_file,
+    write_storage_file,
+)
+import meadowrun.func_worker_storage_helper
 
 _GIT_REPO_URL_SUFFIXES_TO_REMOVE = [".git", "/"]
 
@@ -166,12 +181,7 @@ async def get_code_paths(
             credentials,
         )
     elif case == "code_zip_file":
-        return await _get_zip_file_code_paths(
-            local_copies_folder,
-            job.code_zip_file.url,
-            job.code_zip_file.code_paths,
-            job.code_zip_file.cwd_path,
-        )
+        return await _get_zip_file_code_paths(local_copies_folder, job.code_zip_file)
     else:
         raise ValueError(f"Unrecognized code_deployment {case}")
 
@@ -250,55 +260,38 @@ async def _get_git_code_paths(
         return ([source_path], local_copy_path, local_copy_path)
 
 
+_ALL_OBJECT_STORAGES = {
+    # see the note on get_url_scheme
+    s.get_url_scheme(): s  # type: ignore
+    for s in [
+        AzureBlobStorage,
+        FuncWorkerClientObjectStorage,
+        LocalObjectStorage,
+        S3ObjectStorage,
+    ]
+}
+
+
 async def _get_zip_file_code_paths(
-    local_copies_folder: str,
-    zip_file_url: str,
-    code_paths: Sequence[str],
-    cwd_path: str,
+    local_copies_folder: str, code_zip_file: CodeZipFile
 ) -> Tuple[List[str], None, str]:
-    decoded_url = urllib.parse.urlparse(zip_file_url)
-    if decoded_url.scheme == "file":
-        with zipfile.ZipFile(decoded_url.path) as zip_file:
-            extracted_folder = os.path.splitext(os.path.basename(decoded_url.path))[0]
-            zip_file.extractall(os.path.join(local_copies_folder, extracted_folder))
-        return (
-            [
-                os.path.join(local_copies_folder, extracted_folder, zip_path)
-                for zip_path in code_paths
-            ],
-            None,
-            os.path.join(local_copies_folder, extracted_folder, cwd_path),
-        )
+    decoded_url = urllib.parse.urlparse(code_zip_file.url)
+    if decoded_url.scheme not in _ALL_OBJECT_STORAGES:
+        raise ValueError(f"Unknown URL scheme in {code_zip_file.url}")
 
-    async def download_and_unzip(
-        download: Callable[[str, str, str], Coroutine[Any, Any, None]],
-    ) -> Tuple[List[str], None, str]:
-        bucket_name = decoded_url.netloc
-        object_name = decoded_url.path.lstrip("/")
-        extracted_folder = os.path.join(local_copies_folder, object_name)
+    object_storage = _ALL_OBJECT_STORAGES[decoded_url.scheme]()
+    extracted_folder = await object_storage.download_and_unzip(
+        code_zip_file.url, local_copies_folder
+    )
 
-        with filelock.FileLock(f"{extracted_folder}.lock", timeout=120):
-            if not os.path.exists(extracted_folder):
-                zip_file_path = extracted_folder + ".zip"
-                await download(bucket_name, object_name, zip_file_path)
-                with zipfile.ZipFile(zip_file_path) as zip_file:
-                    zip_file.extractall(
-                        os.path.join(local_copies_folder, extracted_folder)
-                    )
-
-        return (
-            [os.path.join(extracted_folder, zip_path) for zip_path in code_paths],
-            None,
-            os.path.join(extracted_folder, cwd_path),
-        )
-
-    if decoded_url.scheme == "s3":
-        return await download_and_unzip(s3.download_file)
-
-    if decoded_url.scheme == "azblob":
-        return await download_and_unzip(blob_storage.download_file)
-
-    raise ValueError(f"Unknown URL scheme in {zip_file_url}")
+    return (
+        [
+            os.path.join(local_copies_folder, extracted_folder, zip_path)
+            for zip_path in code_zip_file.code_paths
+        ],
+        None,
+        os.path.join(local_copies_folder, extracted_folder, code_zip_file.cwd_path),
+    )
 
 
 async def compile_environment_spec_to_container(
@@ -446,6 +439,70 @@ async def compile_environment_spec_to_container(
     return result
 
 
+async def compile_environment_spec_locally(
+    environment_spec: Union[EnvironmentSpecInCode, EnvironmentSpec],
+    interpreter_spec_path: str,
+    built_interpreters_folder: str,
+) -> ServerAvailableInterpreter:
+    """
+    Turns e.g. a conda_environment.yml file into a locally available python interpreter
+    """
+    path_to_spec, spec_hash, has_git_dependency = _get_path_and_hash(
+        environment_spec, interpreter_spec_path
+    )
+    # we don't have to worry about has_git_dependency as we assume we always have git
+    # installed in this environment
+
+    print(f"Building python environment locally {spec_hash}")
+
+    # TODO we shouldn't install apt packages but we should check to see whether they're
+    # installed
+    # apt_packages = [
+    #     p for p in environment_spec.additional_software.keys() if p != "cuda"
+    # ]
+
+    if environment_spec.environment_type == EnvironmentType.CONDA:
+        get_cached_or_create: Callable[
+            [str, str, str, Callable[[str, str], bool], Callable[[str, str], None]],
+            Awaitable[str],
+        ] = get_cached_or_create_conda_environment
+    elif environment_spec.environment_type == EnvironmentType.PIP:
+        get_cached_or_create = get_cached_or_create_pip_environment
+    elif environment_spec.environment_type == EnvironmentType.POETRY:
+        get_cached_or_create = get_cached_or_create_poetry_environment
+    else:
+        raise ValueError(
+            f"Unexpected environment_type {environment_spec.environment_type}"
+        )
+
+    return ServerAvailableInterpreter(
+        interpreter_path=await get_cached_or_create(
+            spec_hash,
+            path_to_spec,
+            os.path.join(built_interpreters_folder, spec_hash),
+            # TODO this isn't the right way to do this--these try_get_storage_file and
+            # write_storage file functions should be getting passed in from higher up.
+            # For now this works because this code path is only being hit from
+            # Kubernetes
+            # try_get_file(remote_file_name: str, local_file_name: str) -> bool. Tries
+            # to download the specified remote file to the specified local file name.
+            # Returns True if the file is available, False if the file is not available.
+            functools.partial(
+                try_get_storage_file,
+                meadowrun.func_worker_storage_helper.FUNC_WORKER_STORAGE_CLIENT,
+                meadowrun.func_worker_storage_helper.FUNC_WORKER_STORAGE_BUCKET,
+            ),
+            # upload_file(local_file_name: str, remote_file_name: str) -> None. Uploads
+            # the specified file, overwrites any existing remote file.
+            functools.partial(
+                write_storage_file,
+                meadowrun.func_worker_storage_helper.FUNC_WORKER_STORAGE_CLIENT,
+                meadowrun.func_worker_storage_helper.FUNC_WORKER_STORAGE_BUCKET,
+            ),
+        )
+    )
+
+
 def _hash_spec(spec_contents: bytes) -> str:
     # TODO better to exclude the name and prefix for conda yml files as those
     # are ignored
