@@ -13,6 +13,7 @@ import sys
 import traceback
 from typing import (
     Any,
+    AsyncIterable,
     Callable,
     Coroutine,
     Dict,
@@ -48,6 +49,7 @@ from meadowrun.credentials import (
     get_matching_credentials,
 )
 from meadowrun.deployment_manager import (
+    compile_environment_spec_locally,
     compile_environment_spec_to_container,
     get_code_paths,
 )
@@ -69,7 +71,10 @@ from meadowrun.run_job_core import (
     CloudProviderType,
     Host,
     JobCompletion,
+    LocalObjectStorage,
     MeadowrunException,
+    ObjectStorage,
+    TaskResult,
 )
 from meadowrun.shared import pickle_exception
 
@@ -355,7 +360,7 @@ async def _launch_non_container_job(
     paths_to_search = env_vars["PATH"]
     if cwd_path:
         working_directory = cwd_path
-        paths_to_search = f"{working_directory};{paths_to_search}"
+        paths_to_search = f"{working_directory}{os.pathsep}{paths_to_search}"
     else:
         # TODO probably cleanest to allocate a new working directory for each job
         #  instead of just using the default
@@ -915,6 +920,7 @@ async def run_local(
     job: Job,
     working_folder: Optional[str] = None,
     cloud: Optional[Tuple[CloudProviderType, str]] = None,
+    compile_environment_in_container: bool = True,
 ) -> Tuple[ProcessState, Optional[asyncio.Task[ProcessState]]]:
     """
     Runs a job locally using the specified working_folder (or uses the default). Meant
@@ -932,6 +938,12 @@ async def run_local(
     NON_ZERO_RETURN_CODE.
 
     If the initial job state is RUN_REQUEST_FAILED, the continuation will be None.
+
+    compile_environment_in_container controls the behavior when job has an environment
+    spec for the interpreter. If compile_environment_in_container is true, environment
+    specs get compiled into container images. If it's false, environment specs are
+    turned into environments in the local environment
+    TODO compile_environment_in_container should probably be part of the Job object.
     """
 
     (
@@ -966,21 +978,36 @@ async def run_local(
                     "Cannot specify environment_spec_in_code and not provide any code "
                     "paths"
                 )
-            job.server_available_container.CopyFrom(
-                await compile_environment_spec_to_container(
-                    job.environment_spec_in_code, interpreter_spec_path, cloud
+            if compile_environment_in_container:
+                job.server_available_container.CopyFrom(
+                    await compile_environment_spec_to_container(
+                        job.environment_spec_in_code, interpreter_spec_path, cloud
+                    )
                 )
-            )
-            interpreter_deployment = "server_available_container"
+                interpreter_deployment = "server_available_container"
+            else:
+                job.server_available_interpreter.CopyFrom(
+                    await compile_environment_spec_locally(
+                        job.environment_spec_in_code, interpreter_spec_path, misc_folder
+                    )
+                )
+                interpreter_deployment = "server_available_interpreter"
 
         if interpreter_deployment == "environment_spec":
-
-            job.server_available_container.CopyFrom(
-                await compile_environment_spec_to_container(
-                    job.environment_spec, misc_folder, cloud
+            if compile_environment_in_container:
+                job.server_available_container.CopyFrom(
+                    await compile_environment_spec_to_container(
+                        job.environment_spec, misc_folder, cloud
+                    )
                 )
-            )
-            interpreter_deployment = "server_available_container"
+                interpreter_deployment = "server_available_container"
+            else:
+                job.server_available_interpreter.CopyFrom(
+                    await compile_environment_spec_locally(
+                        job.environment_spec, misc_folder, misc_folder
+                    )
+                )
+                interpreter_deployment = "server_available_interpreter"
 
         # then decide if we're running in a container or not
 
@@ -1152,8 +1179,16 @@ async def run_local(
 @dataclasses.dataclass(frozen=True)
 class LocalHost(Host):
     async def run_job(
-        self, resources_required: Optional[ResourcesInternal], job: Job
+        self,
+        resources_required: Optional[ResourcesInternal],
+        job: Job,
+        wait_for_result: bool,
     ) -> JobCompletion[Any]:
+        if not wait_for_result:
+            raise NotImplementedError(
+                "wait_for_result=False is not supported for LocalHost yet"
+            )
+
         if resources_required is not None:
             raise ValueError("Specifying Resources for LocalHost is not supported")
 
@@ -1193,5 +1228,22 @@ class LocalHost(Host):
         job_fields: Dict[str, Any],
         num_concurrent_tasks: int,
         pickle_protocol: int,
-    ) -> Sequence[_U]:
+        wait_for_result: bool,
+    ) -> Optional[Sequence[_U]]:
         raise NotImplementedError("run_map on LocalHost is not implemented")
+
+    def run_map_as_completed(
+        self,
+        function: Callable[[_T], _U],
+        args: Sequence[_T],
+        resources_required_per_task: Optional[ResourcesInternal],
+        job_fields: Dict[str, Any],
+        num_concurrent_tasks: int,
+        pickle_protocol: int,
+    ) -> AsyncIterable[TaskResult[_U]]:
+        raise NotImplementedError(
+            "run_map_as_completed is not implemented for LocalHost"
+        )
+
+    async def get_object_storage(self) -> ObjectStorage:
+        return LocalObjectStorage()
